@@ -1,41 +1,48 @@
 #!/usr/bin/env python
 # -*- coding: latin-1 -*-
+# pylint: disable=invalid-name
 
 """
-Mandelbrot Set. (October 4, 2014)
+Mandelbrot Set simple computation.
 
 See http://en.wikipedia.org/wiki/Mandelbrot_set#Computer_drawings .
 
 Piece of SimpleGUICS2Pygame.
 https://bitbucket.org/OPiMedia/simpleguics2pygame
 
-GPLv3 --- Copyright (C) 2013, 2014 Olivier Pirson
-http://www.opimedia.be/
+:license: GPLv3 --- Copyright (C) 2013-2014, 2020 Olivier Pirson
+:author: Olivier Pirson --- http://www.opimedia.be/
+:version: May 21, 2020
 """
 
 import math
 
 try:
-    from user38_ZmhOVHGm2lhVRhk import codeskulptor_is, hex2
+    from typing import List, Optional, Tuple
+except ImportError:
+    pass
 
-    import simplegui
+try:
+    from user305_SXBsmszNiUxIeoV import codeskulptor_is, hex2  # pytype: disable=import-error  # noqa
 
-    from codeskulptor import set_timeout
+    import simplegui  # pytype: disable=import-error
+
+    from codeskulptor import set_timeout  # pytype: disable=import-error
 
     set_timeout(10)
 except ImportError:
     from SimpleGUICS2Pygame.codeskulptor_lib import codeskulptor_is, hex2
 
-    import SimpleGUICS2Pygame.simpleguics2pygame as simplegui
+    import SimpleGUICS2Pygame.simpleguics2pygame as simplegui  # type: ignore
 
-    simplegui.Frame._hide_status = True
+    simplegui.Frame._hide_status = True  # pylint: disable=protected-access
 
 
 #
 # Global constants
 ###################
-_FPS_AVERAGE = not codeskulptor_is()  # draw FPS average
-                                      #   (only with SimpleGUICS2Pygame)
+# draw FPS average (only with SimpleGUICS2Pygame)
+_FPS_AVERAGE = not codeskulptor_is()
 
 CANVAS_WIDTH = 256
 CANVAS_HEIGHT = 256
@@ -44,35 +51,39 @@ CANVAS_HEIGHT = 256
 #
 # Global variables
 ###################
-colors = None
+COLORS = None  # type:  Optional[Tuple[str, ...]]
 
-grid = None
+GRID = None  # type: Optional[List[List[List]]]
 
-nb_iter_max = 50
-nb_iter = 0
+NB_ITER_MAX = 50
+NB_ITER = 0
 
-z0_real = -2.0
-z0_imag = 1.5
+Z0_REAL = -2.0
+Z0_IMAG = 1.5
 
-z1_real = 1.0
-z1_imag = -1.5
+Z1_REAL = 1.0
+Z1_IMAG = -1.5
 
 
 #
 # Functions
 ############
-def draw_and_calculate(canvas):
+def draw_and_calculate(canvas):  # pylint: disable=too-many-branches
+    # type: (simplegui.Canvas) -> None
     """
-    Draw and calculate image of Mandelbrot set from grid.
+    Draw and calculate image of Mandelbrot set from GRID.
 
     :param canvas: simplegui.Canvas
     """
-    global nb_iter
+    global NB_ITER  # pylint: disable=global-statement
 
-    print(nb_iter)
-    nb_iter += 1
+    assert isinstance(COLORS, tuple)
+    assert isinstance(GRID, list)
 
-    for y, line in enumerate(grid):
+    print(NB_ITER)
+    NB_ITER += 1
+
+    for y, line in enumerate(GRID):
         contiguous_color = None
         contiguous_x0 = 0
 
@@ -81,64 +92,66 @@ def draw_and_calculate(canvas):
             if color is None:
                 z = point[0]
 
-                z_real2 = z[0]*z[0]
-                z_imag2 = z[1]*z[1]
+                z_real2 = z[0] * z[0]
+                z_imag2 = z[1] * z[1]
                 z_abs2 = z_real2 + z_imag2
 
                 if z_abs2 > 4:
-                    point[3] = color = point[2] % len(colors)  # color
+                    color = point[2] % len(COLORS)  # color
+                    point[3] = color
                 else:
                     color = None
                     c = point[1]
                     point[0] = (z_real2 - z_imag2 + c[0],  # z
-                                z[0]*z[1]*2 + c[1])
+                                z[0] * z[1] * 2 + c[1])
                     point[2] += 1  # number of iterations
 
             if contiguous_color != color:
                 if contiguous_color is not None:
-                    contiguous_color = colors[contiguous_color]
+                    contiguous_color_str = COLORS[contiguous_color]
                     if contiguous_x0 + 1 == x:
                         canvas.draw_point((contiguous_x0, y),
-                                          contiguous_color)
+                                          contiguous_color_str)
                         canvas.draw_point((contiguous_x0, CANVAS_HEIGHT - y),
-                                          contiguous_color)
+                                          contiguous_color_str)
                     else:
                         draw_hline(canvas,
                                    contiguous_x0, x - 1, y,
-                                   contiguous_color)
+                                   contiguous_color_str)
                         draw_hline(canvas,
                                    contiguous_x0, x - 1, CANVAS_HEIGHT - y,
-                                   contiguous_color)
+                                   contiguous_color_str)
 
                 contiguous_color = color
                 contiguous_x0 = x
 
         if contiguous_color is not None:
-            contiguous_color = colors[contiguous_color]
+            contiguous_color_str = COLORS[contiguous_color]
             if contiguous_x0 + 1 == len(line):
                 canvas.draw_point((contiguous_x0, y),
-                                  contiguous_color)
+                                  contiguous_color_str)
                 canvas.draw_point((contiguous_x0, CANVAS_HEIGHT - y),
-                                  contiguous_color)
+                                  contiguous_color_str)
             else:
                 draw_hline(canvas,
                            contiguous_x0, len(line) - 1, y,
-                           contiguous_color)
+                           contiguous_color_str)
                 draw_hline(canvas,
                            contiguous_x0, len(line) - 1, CANVAS_HEIGHT - y,
-                           contiguous_color)
+                           contiguous_color_str)
 
-    if nb_iter >= nb_iter_max:
+    if NB_ITER >= NB_ITER_MAX:
         frame.set_draw_handler(draw_only)
         print('\nEnd.')
 
     if _FPS_AVERAGE:
-        canvas.draw_text('{:.3}'.format(frame._get_fps_average()), (5, 20),
-                         20, 'Black')
+        canvas.draw_text('{:.3}'.format(frame._get_fps_average()),  # pylint: disable=protected-access  # noqa
+                         (5, 20), 20, 'Black')
 
 
 if codeskulptor_is():
     def draw_hline(canvas, x0, x1, y, color):
+        # type: (simplegui.Canvas, int, int, int, str) -> None
         """
         Draw a horizontal line
         (point by point
@@ -154,6 +167,7 @@ if codeskulptor_is():
             canvas.draw_point((x, y), color)
 else:
     def draw_hline(canvas, x0, x1, y, color):
+        # type: (simplegui.Canvas, int, int, int, str) -> None
         """
         Draw a horizontal line.
 
@@ -166,13 +180,16 @@ else:
         canvas.draw_line((x0, y), (x1, y), 1, color)
 
 
-def draw_only(canvas):
+def draw_only(canvas):  # type: (simplegui.Canvas) -> None
     """
-    Draw image of Mandelbrot set from grid.
+    Draw image of Mandelbrot set from GRID.
 
     :param canvas: simplegui.Canvas
     """
-    for y, line in enumerate(grid):
+    assert isinstance(COLORS, tuple)
+    assert isinstance(GRID, list)
+
+    for y, line in enumerate(GRID):
         contiguous_color = None
         contiguous_x0 = 0
 
@@ -180,79 +197,81 @@ def draw_only(canvas):
             color = point[3]
             if contiguous_color != color:
                 if contiguous_color is not None:
-                    contiguous_color = colors[contiguous_color]
+                    contiguous_color_str = COLORS[contiguous_color]
                     if contiguous_x0 + 1 == x:
                         canvas.draw_point((contiguous_x0, y),
-                                          contiguous_color)
+                                          contiguous_color_str)
                         canvas.draw_point((contiguous_x0, CANVAS_HEIGHT - y),
-                                          contiguous_color)
+                                          contiguous_color_str)
                     else:
                         draw_hline(canvas,
                                    contiguous_x0, x - 1, y,
-                                   contiguous_color)
+                                   contiguous_color_str)
                         draw_hline(canvas,
                                    contiguous_x0, x - 1, CANVAS_HEIGHT - y,
-                                   contiguous_color)
+                                   contiguous_color_str)
 
                 contiguous_color = color
                 contiguous_x0 = x
 
-        contiguous_color = colors[contiguous_color]
+        assert isinstance(contiguous_color, int)
+
+        contiguous_color_str = COLORS[contiguous_color]
         if contiguous_x0 + 1 == len(line):
             canvas.draw_point((contiguous_x0, y),
-                              contiguous_color)
+                              contiguous_color_str)
             canvas.draw_point((contiguous_x0, CANVAS_HEIGHT - y),
-                              contiguous_color)
+                              contiguous_color_str)
         else:
             draw_hline(canvas,
                        contiguous_x0, len(line) - 1, y,
-                       contiguous_color)
+                       contiguous_color_str)
             draw_hline(canvas,
                        contiguous_x0, len(line) - 1, CANVAS_HEIGHT - y,
-                       contiguous_color)
+                       contiguous_color_str)
 
     if _FPS_AVERAGE:
-        canvas.draw_text('{:.3}'.format(frame._get_fps_average()), (5, 20),
-                         20, 'Black')
+        canvas.draw_text('{:.3}'.format(frame._get_fps_average()),  # pylint: disable=protected-access  # noqa
+                         (5, 20), 20, 'Black')
 
 
-def init():
+def init():  # type: () -> None
     """
-    Set a grid of point information :
+    Set a GRID of point information :
     [z, C, numbers of iterations, None or color number]
     """
-    global colors
-    global grid
-    global nb_iter
+    global COLORS  # pylint: disable=global-statement
+    global GRID  # pylint: disable=global-statement
+    global NB_ITER  # pylint: disable=global-statement
 
     print('Init.')
 
-    assert nb_iter_max < 256, nb_iter_max
+    assert NB_ITER_MAX < 256, NB_ITER_MAX
 
-    colors = tuple(['#%s%s%s'
-                    % (hex2(255 - 256*int(math.log10(i)//nb_iter_max)),
-                       hex2(255 - 256*i//nb_iter_max),
-                       hex2(255 - 256*i//nb_iter_max))
-                    for i in range(1, nb_iter_max)])
+    COLORS = tuple(['#%s%s%s'
+                    % (hex2(255 - 256 * int(math.log10(i) // NB_ITER_MAX)),
+                       hex2(255 - 256 * i // NB_ITER_MAX),
+                       hex2(255 - 256 * i // NB_ITER_MAX))
+                    for i in range(1, NB_ITER_MAX)])
 
-    nb_iter = 0
+    NB_ITER = 0
 
-    coef_c_real = (z1_real - z0_real)/(CANVAS_WIDTH - 1)
-    coef_c_imag = (z0_imag - z1_imag)/(CANVAS_HEIGHT - 1)
+    coef_c_real = (Z1_REAL - Z0_REAL) / (CANVAS_WIDTH - 1)
+    coef_c_imag = (Z0_IMAG - Z1_IMAG) / (CANVAS_HEIGHT - 1)
 
-    grid = []
-    for y in range(CANVAS_HEIGHT//2 + 1):
-        c_imag = z0_imag - coef_c_imag*y
+    GRID = []
+    for y in range(CANVAS_HEIGHT // 2 + 1):
+        c_imag = Z0_IMAG - coef_c_imag * y
 
         line = []
         for x in range(CANVAS_WIDTH):
-            c_real = z0_real + coef_c_real*x
+            c_real = Z0_REAL + coef_c_real * x
             line.append([(0, 0),            # z
                          (c_real, c_imag),  # C
                          0,                 # number of iterations
                          None])             # color number
 
-        grid.append(line)
+        GRID.append(line)
 
     print('\nNumber of iterations:')
 
